Computes the adjusted significance level at step \(i\) of \(m\)
tests in the sequential selection procedure of Benjamini &
Gavrilov (2009), as used by pinSearch() when control_fdr = TRUE:
Details
$$\frac{iq}{m + 1 - i(1 - q)}$$ where \(i\) is the step index in the search, \(m\) is the maximum number of constraints that can be freed, and \(q\) is the target significance level.
Note that \(i\) is defined for \(1 <= i <= m\), with
\(m >= 1\) and \(0 < q < 1\). These bounds are maintained by
the internal logic of pinSearch(), but external callers must
ensure them on their own.